.. image:: https://img.shields.io/pypi/v/schemadict.svg?style=flat
   :target: https://pypi.org/project/schemadict/
   :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/schemadict/badge/?version=latest
    :target: https://schemadict.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/license-Apache%202-blue.svg
    :target: https://github.com/airinnova/schemadict/blob/master/LICENSE.txt
    :alt: License

.. image:: https://travis-ci.org/airinnova/schemadict.svg?branch=master
    :target: https://travis-ci.org/airinnova/schemadict
    :alt: Build status

.. image:: https://codecov.io/gh/airinnova/schemadict/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/airinnova/schemadict
    :alt: Coverage

|

.. image:: https://raw.githubusercontent.com/airinnova/schemadict/master/docs/source/_static/images/logo/logo.png
   :target: https://github.com/airinnova/schemadict/
   :alt: logo

TODO

Installation
============

*Schemadict* is available on `PyPI <https://pypi.org/project/schemadict/>`_ and may simply be installed with

.. code::

    pip install schemadict

License
=======

**License:** Apache-2.0
